# -*- coding: utf-8 -*-
##----------------------------------------------------------------------
## Vendor: Eltex
## OS:     MES
##----------------------------------------------------------------------
## Copyright (C) 2007-2011 The NOC Project
## See LICENSE for details
##----------------------------------------------------------------------

## NOC modules
import noc.sa.profiles
from noc.sa.protocols.sae_pb2 import TELNET, SSH


class Profile(noc.sa.profiles.Profile):
    name = "Eltex.MES"
    supported_schemes = [TELNET, SSH]
    pattern_username = r"^User Name:"
    pattern_password = r"^Password:"
    pattern_more = r"^More: <space>,  Quit: q, One line: <return>$"
    pattern_unpriveleged_prompt = r"^\S+> "
    pattern_syntax_error = r"^% (Unrecognized command|Incomplete command|Wrong number of parameters or invalid range, size or characters entered)$"
    command_disable_pager = "terminal datadump"
    command_super = "enable"
    command_enter_config = "configure"
    command_leave_config = "end"
    command_save_config = "copy running-config startup-config"
    pattern_prompt = r"^\S+# "
#    requires_netmask_conversion = True
#    convert_mac = noc.sa.profiles.Profile.convert_mac_to_cisco
#    config_volatile = ["^ntp clock-period .*?^"]

    def convert_interface_name(self, interface):
        if interface.lower().startswith("dot11radio"):
            return "Dot11Radio" + interface[10:]
        if interface.lower().startswith("bvi"):
            return "BVI" + interface[3:]
        return self.convert_interface_name_cisco(interface)

    def generate_prefix_list(self, name, pl, strict=True):
        p = "ip prefix-list %s permit %%s" % name
        if not strict:
            p += " le 32"
        return "no ip prefix-list %s\n" % name + "\n".join([p % x for x in pl])

    def setup_session(self, script):
        """
        Perform session initialization
        Process specific path parameters:
        cluster:id - switch to cluster member
        """
        cluster_member = None
        # Parse path parameters
        for p in script.access_profile.path.split("/"):
            if p.startswith("cluster:"):
                cluster_member = p[8:].strip()
        # Switch to cluster member, if necessary
        if cluster_member:
            script.debug("Switching to cluster member '%s'" % cluster_member)
            script.cli("rc %s" % cluster_member)


def uBR(v):
    """
    uBR series selector
    """
    return "BC" in v["version"]
