# -*- coding: utf-8 -*-
##----------------------------------------------------------------------
## Eltex.MES.get_staticvlans
##----------------------------------------------------------------------
## Copyright (C) 2007-2011 The NOC Project
## See LICENSE for details
##----------------------------------------------------------------------

## Python modules
import re
## NOC modules
from noc.sa.script import Script as NOCScript
from noc.staticvlan.models import ranges_to_list_str
from noc.sa.interfaces import IGetStaticVlans

rx_interface = re.compile(r"^(?P<interface>\S+)\s+\S+\s+(Full|Half)\s+\d+\s+\S+\s+\S+\s+(Up|Down)\s+\S+\s+\S\s*", re.MULTILINE)
rx_vlan = re.compile(r"^\s*(?P<vlan>\d+)\s+(?P<name>.+?)\s+(?P<rule>\S+)\s+(?P<type>\S+)\s*", re.IGNORECASE)
rx_vlanf = re.compile(r"^\s*(?P<vlan>\d+)\s+(?P<name>.+?)\s*",  re.IGNORECASE)

# To do advertisement
#rx_advertisement=re.compile(r"^VLAN Type\s+:\s+Static+\s+Advertisement+\s+:\s+(?P<advertisement>\S+)",re.IGNORECASE)

class Script(NOCScript):
    name = "Eltex.MES.get_staticvlans"
    implements = [IGetStaticVlans]


    def execute(self):
        rv = {}
#        for match in rx_interface.finditer(self.cli("show interfaces status")):
        for match in rx_interface.finditer(self.cli("show interfaces configuration")):
            interface = match.group("interface")
            for vlans in self.cli("show interfaces switchport %s"%interface).splitlines():
                vlan = rx_vlan.match(vlans)
                if vlan:
                    if vlan.group("type") == "Static":
                        vlan_id = vlan.group("vlan")
                        if vlan_id not in rv:
                            rv.update({ vlan_id : {
                                                "name"      : vlan.group("name"),
                                                "tagged"    : [],
                                                "untagged"  : [],
                                                "forbidden" : [],
                                                }
                                    })
                        rule = vlan.group("rule")
                        if rule == "Tagged":
                            rv[vlan_id]["tagged"].append(interface)
                        elif rule == "Untagged":
                            rv[vlan_id]["untagged"].append(interface)
                else:
                    vlanf = rx_vlanf.match(vlans)
                    if vlanf:
                        vlan_id = vlanf.group("vlan")
                        if vlan_id not in rv:
                            rv.update({ vlan_id : {
                                                "name"      : vlan.group("name"),
                                                "tagged"    : [],
                                                "untagged"  : [],
                                                "forbidden" : [],
                                                }
                                    })
                        rv[vlan_id]["forbidden"].append(interface)
        r=[]
        for vlan_id in rv:
            r.append({
                    "vlan"          : vlan_id,
                    "name"          : rv[vlan_id]["name"],
                    "tagged"        : ", ".join(rv[vlan_id]["tagged"]),
                    "untagged"      : ", ".join(rv[vlan_id]["untagged"]),
                    "forbidden"     : ", ".join(rv[vlan_id]["forbidden"]),
                    "advertisement" : False,
                    })
        return r
